@@ -301,6 +301,13 @@ class _config(_base_config):
     _oauth_extra_params = param.Dict(default={}, doc="""
         Additional parameters required for OAuth provider.""")
 
+    _oauth_guest_endpoints = param.List(default=None, doc="""
+        List of endpoints that can be accessed as a guest without authenticating.""")
+
+    _oauth_optional = param.Boolean(default=False, doc="""
+        Whether the user will be forced to go through login flow or if
+        they can access all applications as a guest.""")
+
     _oauth_refresh_tokens = param.Boolean(default=False, doc="""
         Whether to automatically refresh access tokens in the background.""")
 
@@ -317,7 +324,8 @@ class _config(_base_config):
         'nthreads', 'oauth_provider', 'oauth_expiry', 'oauth_key',
         'oauth_secret', 'oauth_jwt_user', 'oauth_redirect_uri',
         'oauth_encryption_key', 'oauth_extra_params', 'npm_cdn',
-        'layout_compatibility', 'oauth_refresh_tokens'
+        'layout_compatibility', 'oauth_refresh_tokens', 'oauth_guest_endpoints',
+        'oauth_optional'
     ]
 
     _truthy = ['True', 'true', '1', True, 1]
@@ -580,6 +588,20 @@ class _config(_base_config):
         else:
             return self._oauth_extra_params
 
+    @property
+    def oauth_guest_endpoints(self):
+        if 'PANEL_OAUTH_GUEST_ENDPOINTS' in os.environ:
+            return ast.literal_eval(os.environ['PANEL_OAUTH_GUEST_ENDPOINTS'])
+        else:
+            return self._oauth_guest_endpoints
+
+    @property
+    def oauth_optional(self):
+        optional = os.environ.get('PANEL_OAUTH_OPTIONAL', self._oauth_optional)
+        if isinstance(optional, bool):
+            return optional
+        return optional.lower() in ('1', 'true')
+
     @property
     def theme(self):
         curdoc = state.curdoc
