@@ -87,7 +87,8 @@ LOGOUT_TEMPLATE = _env.get_template('logout.html')
 BASIC_LOGIN_TEMPLATE = _env.get_template('basic_login.html')
 DEFAULT_TITLE = "Panel Application"
 JS_RESOURCES = _env.get_template('js_resources.html')
-CDN_URL = f"https://cdn.holoviz.org/panel/{JS_VERSION}/"
+CDN_ROOT = "https://cdn.holoviz.org/panel/"
+CDN_URL = f"{CDN_ROOT}{JS_VERSION}/"
 CDN_DIST = f"{CDN_URL}dist/"
 DOC_DIST = "https://panel.holoviz.org/_static/"
 LOCAL_DIST = "static/extensions/panel/"
@@ -216,7 +217,10 @@ def resolve_custom_path(
         abs_path = path
     else:
         abs_path = module_path / path
-    if not abs_path.is_file():
+    try:
+        if not abs_path.is_file():
+            return None
+    except OSError:
         return None
     abs_path = abs_path.resolve()
     if not relative:
@@ -372,8 +376,9 @@ def bundle_resources(roots, resources, notebook=False, reloading=False, enable_m
     extensions = _bundle_extensions(None, js_resources)
     if reloading:
         extensions = [
-            ext for ext in extensions if not ext.cdn_url.startswith('https://unpkg.com/@holoviz/panel@')
+            ext for ext in extensions if not (ext.cdn_url is not None and ext.cdn_url.startswith('https://unpkg.com/@holoviz/panel@'))
         ]
+
     extra_js = []
     if mode == "inline":
         js_raw.extend([ Resources._inline(bundle.artifact_path) for bundle in extensions ])
@@ -382,6 +387,8 @@ def bundle_resources(roots, resources, notebook=False, reloading=False, enable_m
             server_url = bundle.server_url
             if resources.root_url and not resources.absolute:
                 server_url = server_url.replace(resources.root_url, '', 1)
+                if state.rel_path:
+                    server_url = f'{state.rel_path}/{server_url}'
             js_files.append(server_url)
     elif mode == "cdn":
         for bundle in extensions:
