@@ -904,7 +904,7 @@ class _state(param.Parameterized):
         """
         Returns the OAuth access_token if enabled.
         """
-        if self.user in self._oauth_user_overrides and 'refresh_token' in self._oauth_user_overrides:
+        if self.user in self._oauth_user_overrides and 'access_token' in self._oauth_user_overrides[self.user]:
             return self._oauth_user_overrides[self.user]['access_token']
         access_token = self._decode_cookie('access_token')
         if not access_token:
@@ -1083,6 +1083,10 @@ class _state(param.Parameterized):
         from tornado.web import decode_signed_value
 
         from ..config import config
+        is_guest = self.cookies.get('is_guest')
+        if is_guest:
+            return "guest"
+
         user = self.cookies.get('user')
         if user is None or config.cookie_secret is None:
             return None
@@ -1093,7 +1097,12 @@ class _state(param.Parameterized):
         """
         Returns the OAuth user information if enabled.
         """
+        is_guest = self.cookies.get('is_guest')
+        if is_guest:
+            return {"user": "guest", "username": "guest"}
         id_token = self._decode_cookie('id_token')
+        if id_token is None:
+            return None
         return decode_token(id_token)
 
 state = _state()
