@@ -1,7 +1,9 @@
 export {AcePlot} from "./ace"
 export {Audio} from "./audio"
 export {BrowserInfo} from "./browser"
+export {Button} from "./button"
 export {Card} from "./card"
+export {CheckboxButtonGroup} from "./checkbox_button_group"
 export {Column} from "./column"
 export {CommManager} from "./comm_manager"
 export {CustomSelect} from "./customselect"
@@ -9,11 +11,11 @@ export {DataTabulator} from "./tabulator"
 export {DatetimePicker} from "./datetime_picker"
 export {DeckGLPlot} from "./deckgl"
 export {ECharts} from "./echarts"
+export {FileDownload} from "./file_download"
 export {HTML} from "./html"
 export {IPyWidget} from "./ipywidget"
 export {JSON} from "./json"
 export {JSONEditor} from "./jsoneditor"
-export {FileDownload} from "./file_download"
 export {KaTeX} from "./katex"
 export {Location} from "./location"
 export {MathJax} from "./mathjax"
@@ -23,12 +25,14 @@ export {Player} from "./player"
 export {PlotlyPlot} from "./plotly"
 export {Progress} from "./progress"
 export {QuillInput} from "./quill"
+export {RadioButtonGroup} from "./radio_button_group"
 export {ReactiveHTML} from "./reactive_html"
 export {SingleSelect} from "./singleselect"
 export {SpeechToText} from "./speech_to_text"
 export {State} from "./state"
 export {Tabs} from "./tabs"
 export {Terminal} from "./terminal"
+export {TextAreaInput} from "./textarea_input"
 export {TextToSpeech} from "./text_to_speech"
 export {TooltipIcon} from "./tooltip_icon"
 export {TrendIndicator} from "./trend"
