@@ -5,12 +5,12 @@ from subprocess import PIPE, Popen
 
 import pytest
 
-try:
-    from playwright.sync_api import expect
-except ImportError:
-    pytestmark = pytest.mark.skip('playwright not available')
+pytest.importorskip("playwright")
+
+from playwright.sync_api import expect
+
+pytestmark = [pytest.mark.jupyter, pytest.mark.ui]
 
-pytestmark = pytest.mark.ui
 
 @pytest.fixture()
 def launch_jupyterlite():
@@ -43,8 +43,14 @@ def test_jupyterlite_execution(launch_jupyterlite, page):
     page.goto("http://localhost:8123/index.html")
 
     page.locator('text="Getting_Started.ipynb"').first.dblclick()
+
+    # Select the kernel
+    if page.locator('.jp-Dialog').count() == 1:
+        page.locator('.jp-select-wrapper > select').select_option('Python (Pyodide)')
+        page.locator('.jp-Dialog-footer > button').nth(1).click()
+
     for _ in range(6):
-        page.locator('[data-command="runmenu:run"]').click()
+        page.locator('button[data-command="notebook:run-cell-and-select-next"]').click()
         page.wait_for_timeout(500)
 
     page.locator('.noUi-handle').click(timeout=120 * 1000)
