@@ -3,11 +3,9 @@ import pathlib
 
 import pytest
 
-try:
-    from playwright.sync_api import expect
-    pytestmark = pytest.mark.ui
-except ImportError:
-    pytestmark = pytest.mark.skip('playwright not available')
+pytest.importorskip("playwright")
+
+from playwright.sync_api import expect
 
 from panel.config import config
 from panel.pane import Markdown
@@ -15,6 +13,8 @@ from panel.tests.util import (
     run_panel_serve, serve_component, unix_only, wait_for_port, write_file,
 )
 
+pytestmark = pytest.mark.ui
+
 
 @unix_only
 @pytest.mark.parametrize('prefix', ['', 'prefix'])
