@@ -8,6 +8,7 @@ import base64
 import datetime as dt
 import inspect
 import json
+import logging
 import numbers
 import os
 import pathlib
@@ -38,6 +39,8 @@ from .checks import (  # noqa
     is_series, isdatetime, isfile, isIn, isurl,
 )
 
+log = logging.getLogger('panel.util')
+
 bokeh_version = Version(bokeh.__version__)
 
 # Bokeh serializes NaT as this value
@@ -247,7 +250,13 @@ def parse_query(query: str) -> dict[str, Any]:
             try:
                 parsed_query[k] = json.loads(v)
             except Exception:
-                parsed_query[k] = ast.literal_eval(v)
+                try:
+                    parsed_query[k] = ast.literal_eval(v)
+                except Exception:
+                    log.warning(
+                        f'Could not parse value {v!r} of query parameter {k}. '
+                        'Parameter will be ignored.'
+                    )
         elif v.lower() in ("true", "false"):
             parsed_query[k] = v.lower() == "true"
         else:
@@ -275,7 +284,7 @@ def base64url_decode(input):
     return base64.urlsafe_b64decode(input)
 
 
-def decode_token(token, signed=True):
+def decode_token(token: str, signed: bool = True) -> dict[str, Any]:
     """
     Decodes a signed or unsigned JWT token.
     """
@@ -501,3 +510,41 @@ def flatten(line):
             yield from flatten(element)
         else:
             yield element
+
+
+def styler_update(styler, new_df):
+    """
+    Updates the todo items on a pandas Styler object to apply to a new
+    DataFrame.
+
+    Arguments
+    ---------
+    styler: pandas.io.formats.style.Styler
+      Styler objects
+    new_df: pd.DataFrame
+      New DataFrame to update the styler to do items
+
+    Returns
+    -------
+    todos: list
+    """
+    todos = []
+    for todo in styler._todo:
+        if not isinstance(todo, tuple):
+            todos.append(todo)
+            continue
+        ops = []
+        for op in todo:
+            if not isinstance(op, tuple):
+                ops.append(op)
+                continue
+            op_fn = str(op[0])
+            if ('_background_gradient' in op_fn or '_bar' in op_fn) and op[1] in (0, 1):
+                applies = np.array([
+                    new_df[col].dtype.kind in 'uif' for col in new_df.columns
+                ])
+                op = (op[0], op[1], applies)
+            ops.append(op)
+        todo = tuple(ops)
+        todos.append(todo)
+    return todos
